@@ -21,7 +21,8 @@ impl Git {
 
 impl Backend for Git {
     fn status(&self) -> BackendResult<StatusInfo> {
-        let output = Process::spawn("git", &["status", "--branch", "--null"])?.wait()?;
+        let output =
+            Process::spawn("git", &["status", "--branch", "--no-rename", "--null"])?.wait()?;
         let mut splits = output.split('\0').map(str::trim);
 
         let header = splits.next().unwrap_or("").into();
@@ -149,7 +150,7 @@ impl Backend for Git {
 
     fn resolve_taking_ours(&self, entries: &[RevisionEntry]) -> BackendResult<()> {
         if entries.is_empty() {
-            Process::spawn("git", &["checkout", ".", "--ours"])?.wait()?;
+            Process::spawn("git", &["checkout", "--ours", "."])?.wait()?;
         } else {
             if !entries
                 .iter()
@@ -160,7 +161,6 @@ impl Backend for Git {
 
             let mut args = Vec::new();
             args.push("checkout");
-            args.push(".");
             args.push("--ours");
             args.push("--");
 
@@ -178,7 +178,7 @@ impl Backend for Git {
 
     fn resolve_taking_theirs(&self, entries: &[RevisionEntry]) -> BackendResult<()> {
         if entries.is_empty() {
-            Process::spawn("git", &["checkout", ".", "--theirs"])?.wait()?;
+            Process::spawn("git", &["checkout", "--theirs", "."])?.wait()?;
         } else {
             if !entries
                 .iter()
@@ -189,7 +189,6 @@ impl Backend for Git {
 
             let mut args = Vec::new();
             args.push("checkout");
-            args.push(".");
             args.push("--theirs");
             args.push("--");
 
@@ -266,7 +265,7 @@ impl Backend for Git {
     }
 
     fn pull(&self) -> BackendResult<()> {
-        Process::spawn("git", &["pull", "--no-ff", "--all"])?.wait()?;
+        Process::spawn("git", &["pull", "--all"])?.wait()?;
         Ok(())
     }
 
@@ -276,7 +275,10 @@ impl Backend for Git {
     }
 
     fn revision_details(&self, revision: &str) -> BackendResult<RevisionInfo> {
-        let message = Process::spawn("git", &["show", "-s", "--format=%B", revision])?;
+        let message = Process::spawn(
+            "git",
+            &["show", "-s", "--format=%B", "--no-renames", revision],
+        )?;
         let changes = Process::spawn(
             "git",
             &[
@@ -382,6 +384,6 @@ fn parse_file_status(s: &str) -> FileStatus {
         Some('C') => FileStatus::Copied,
         Some('U') => FileStatus::Unmerged,
         Some(' ') => FileStatus::Clean,
-        _ => panic!("unknown file status '{}'", s),
+        _ => FileStatus::Unknown(s.into()),
     }
 }
