@@ -212,7 +212,7 @@ impl Backend for Hg {
             if line == "~" {
                 continue;
             }
-        
+
             let mut splits = line.splitn(6, '\x1f');
 
             let graph = splits.next().unwrap_or("").into();
@@ -334,6 +334,6 @@ fn parse_file_status(s: &str) -> FileStatus {
         "!" => FileStatus::Missing,
         "I" => FileStatus::Ignored,
         "C" => FileStatus::Clean,
-        _ => panic!("unknown file status '{}'", s),
+        _ => FileStatus::Unknown(s.into()),
     }
 }
